(* $Id: godi_query.mli 712 2007-07-30 23:15:47Z gerd $
 * ----------------------------------------------------------------------
 * Copyright 2003 by Gerd Stolpmann.
 *
 * This file is part of godi-tools.
 *
 * godi-tools is free software; you can redistribute it and/or modify it
 * under the conditions in the file LICENSE.
 *
 * godi-tools is distributed WITHOUT ANY WARRANTY, as detailed in the
 * file LICENSE.
 *)

(* Query the databases of available and installed packages *)

open Godi_types
open Godi_exec
open Godi_versions

val godi_conf : unit -> string
  (* Returns the location of godi.conf *)

val localbase : unit -> string
  (* Returns the value of LOCALBASE *)

val pkgdbdir : unit -> string
  (* Returns the value of PKG_DBDIR *)

val buildbase : unit -> string
  (* Returns the build directory, i.e. $LOCALBASE/build *)

val shlib_type : unit -> string
  (* Returns the type of shared library *)

val wget : unit -> string
  (* The absolute path to the wget program *)

val have_ocamlopt : unit -> bool
val have_ocamloptp : unit -> bool
val have_ocamldll : unit -> bool
  (* Returns whether the corresponding features are available *)

val get_tools_makefile : unit -> string
  (* Returns a path to the godi_tools.mk file *)

(* Note: if one of the above functions runs into a problem, User_error
 * will be raised
 *)

val read_text_file : ?pref_user_error:bool -> ?default:string -> 
                     string -> string
  (* Reads the text file, and returns its contents as string. 
   * If the file does not exist, and a [default] is passed, that is
   * returned instead. Otherwise, it is an error if the file does not exist.
   *)


val read_optional_text_file : ?pref_user_error:bool -> string -> string option
  (* Reads the file, and returns its contents as string. If the file
   * does not exist, [None] is returned.
   *)


val query_makefile :
      ?pref_user_error:bool ->
      ?godi_conf:string ->
      ?makefile:string ->
      console ->
      string  ->
      string list ->
        string list
  (* query_makefile directory varnames: chdir to directory, and query the
   * values of varnames using "show-vars".
   * TODO: Move to Godi_make.
   *
   * pref_user_error: Whether to prefer User_error over other exceptions.
   *)


val scan_source_packages :
      ?rescan:bool ->
      console ->
	package list

val forget_source_packages : unit -> unit

val get_installed_packages :
      ?verbose:bool ->
      console ->
	package list
  (** Returns the in-memory representation of the installed packages.
   * Note that there is always only one global list of installed packages,
   * because there is only one package database.
   *
   * @param verbose If true, messages are printed to the protocol when
   * the list is reloaded or reconciled.
   *)

val get_this_installed_package : ?verbose:bool ->
				 console -> string -> package
  (** Returns the package with the passed name (w/o version suffix).
   * Raises [Not_found] if the package does not exist.
   *
   * @param verbose See [get_installed_packages]
   *)


val notify_about_change_of_installed_packages :
      console -> [ `Reload | `Reconcile ] -> unit
  (** Notifies that the packages have been added or deleted, and that the
   * in-memory representation of the installation set is out of date.
   *
   * - [`Reload]: The next call of [get_installed_packages] will reload
   *   all package definitions
   * - [`Reconcile]: The next call of [get_installed_packages] will
   *   check which packages are new, deleted, or modified, by comparing
   *   the files on disk with the in-memory representation, and will only
   *   load the changes.
   *
   * [`Reload] beats [`Reconcile].
   *)

val get_binary_package : string -> package
  (** Reads the metainformation at the beginning of a .tgz file *)


val matches_dep : package -> dependency -> bool

(*
val error_msg : exn -> string
*)
